<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>404 - Not Found</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100 flex flex-col items-center justify-center min-h-screen">
    <div class="text-center">
        <h1 class="text-6xl md:text-8xl font-bold text-red-500 mb-4">
            404
        </h1>
        <p class="text-2xl text-gray-700 font-semibold mb-6">
            Page Not Found
        </p>
        <p class="text-lg text-gray-500 mb-8">
            The page you are looking for does not exist.
        </p>
        <a href="/" class="px-6 py-3 bg-blue-600 text-white font-medium rounded-lg shadow-md hover:bg-blue-700 transition duration-300">
            Go back to home
        </a>
    </div>
</body>
</html>